use bytemuck;
use std::mem;
use wgpu;

#[repr(C)]
#[derive(Debug, Copy, Clone, Default, bytemuck::Pod, bytemuck::Zeroable)]
// Uniforms require uniform alignment.
// Since the largest value in this array is a [f32; 2],
// all smaller values must be padded.
// also, [f32; 3] are aligned as [f32; 4]
// (since alignments must be powers of two)
pub struct GlobalDataContent {
	/// Camera position, in game units
	pub camera_position: [f32; 2],

	/// Camera zoom value, in game units.
	/// Second component is ignored.
	pub camera_zoom: [f32; 2],

	/// Camera zoom min and max.
	pub camera_zoom_limits: [f32; 2],

	/// Size ratio of window, in physical pixels
	pub window_size: [f32; 2],

	/// Physical pixel to logical pixel conversion factor.
	/// Second component is ignored.
	pub window_scale: [f32; 2],

	/// Aspect ratio of window
	/// Second component is ignored.
	pub window_aspect: [f32; 2],

	/// Index of starfield sprite
	/// Second component is ignored.
	pub starfield_sprite: [u32; 2],

	// Size of (square) starfield tiles, in game units
	/// Second component is ignored.
	pub starfield_tile_size: [f32; 2],

	/// Min and max starfield star size, in game units
	pub starfield_size_limits: [f32; 2],

	/// Current game time, in seconds.
	/// Second component is ignored.
	pub current_time: [f32; 2],
}

impl GlobalDataContent {
	pub const SIZE: u64 = mem::size_of::<Self>() as wgpu::BufferAddress;
}
