use bytemuck::{Pod, Zeroable};
use galactica_constants::SPRITE_LIMIT;
use std::mem;
use wgpu;

#[repr(C)]
#[derive(Debug, Copy, Clone, Pod, Zeroable, Default)]
pub struct SpriteData {
	// Animation parameters
	pub frame_count: u32,
	pub repeatmode: u32,
	pub aspect: f32,
	pub frame_duration: f32,

	// Index of first frame in ImageLocationArray
	pub first_frame: u32,
	// stride must be a multiple of 16
	pub _padding: [f32; 3],
}

#[derive(Debug, Copy, Clone)]
pub struct SpriteDataArray {
	pub data: [SpriteData; SPRITE_LIMIT as usize],
}

unsafe impl Pod for SpriteDataArray {}
unsafe impl Zeroable for SpriteDataArray {
	fn zeroed() -> Self {
		Self {
			data: [SpriteData::zeroed(); SPRITE_LIMIT as usize],
		}
	}
}

impl Default for SpriteDataArray {
	fn default() -> Self {
		Self::zeroed()
	}
}

impl SpriteDataArray {
	pub const SIZE: u64 = mem::size_of::<Self>() as wgpu::BufferAddress;
}
